@@ -1,6 +1,6 @@
 #! /bin/sh
 
-# $Id: autogen.sh 851 2006-06-14 17:43:04Z newren $
+# $Id$
 #
 # Copyright (c) 2002  Daniel Elstner  <daniel.elstner@gmx.net>,
 #               2003  Murray Cumming  <murrayc@usa.net>
@@ -59,11 +59,9 @@ echo "- intltoolize."		&& \
 echo "- libtoolize."		&& \
   libtoolize --copy --force --automake 	&& \
 echo "- gnome-doc-prepare."	&& \
-  gnome-doc-prepare --force 	&& \
+  gnome-doc-prepare --force --copy	&& \
 echo "- aclocal-1.9"		&& \
   aclocal-1.9 -I "$srcdir/macros" $ACLOCAL_FLAGS && \
-echo "- autoheader"		&& \
-  autoheader			&& \
 echo "- autoconf"		&& \
   autoconf			&& \
 echo "- automake-1.9."		&& \
