@@ -18,15 +18,17 @@
  * Boston, MA 02111-1307, USA.
  */
 
-#include "dialog_group_by.h"
-#include <glom/libglom/data_structure/glomconversions.h>
+#include <glom/layout_item_dialogs/dialog_group_by.h>
+#include <libglom/data_structure/glomconversions.h>
+#include <glom/utils_ui.h>
+#include <glom/glade_utils.h>
 #include <sstream> //For stringstream
 #include <glibmm/i18n.h>
 
 namespace Glom
 {
 
-Dialog_GroupBy::Dialog_GroupBy(BaseObjectType* cobject, const Glib::RefPtr<Gnome::Glade::Xml>& refGlade)
+Dialog_GroupBy::Dialog_GroupBy(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& builder)
 : Gtk::Dialog(cobject),
   m_label_group_by(0),
   m_label_sort_by(0),
@@ -39,16 +41,16 @@ Dialog_GroupBy::Dialog_GroupBy(BaseObjectType* cobject, const Glib::RefPtr<Gnome
   m_dialog_choose_secondary_fields(0),
   m_dialog_choose_sort_fields(0)
 {
-  refGlade->get_widget("label_group_by", m_label_group_by);
-  refGlade->get_widget("label_sort_by", m_label_sort_by);
-  refGlade->get_widget("label_secondary_fields", m_label_secondary_fields);
+  builder->get_widget("label_group_by", m_label_group_by);
+  builder->get_widget("label_sort_by", m_label_sort_by);
+  builder->get_widget("label_secondary_fields", m_label_secondary_fields);
 
-  refGlade->get_widget("button_select_group_by", m_button_field_group_by);
-  refGlade->get_widget("button_formatting_group_by", m_button_formatting_group_by);
-  refGlade->get_widget("button_select_sort_by", m_button_field_sort_by);
-  refGlade->get_widget("button_secondary_edit", m_button_secondary_fields);
+  builder->get_widget("button_select_group_by", m_button_field_group_by);
+  builder->get_widget("button_formatting_group_by", m_button_formatting_group_by);
+  builder->get_widget("button_select_sort_by", m_button_field_sort_by);
+  builder->get_widget("button_secondary_edit", m_button_secondary_fields);
 
-  refGlade->get_widget_derived("comboboxentry_border_width", m_comboboxentry_border_width);
+  builder->get_widget_derived("comboboxentry_border_width", m_comboboxentry_border_width);
 
   //Connect signals:
   m_button_field_group_by->signal_clicked().connect(sigc::mem_fun(*this, &Dialog_GroupBy::on_button_field_group_by));
@@ -128,7 +130,7 @@ void Dialog_GroupBy::on_button_field_sort_by()
 {
   if(!m_dialog_choose_sort_fields)
   {
-    Glib::RefPtr<Gnome::Glade::Xml> refXml = Gnome::Glade::Xml::create(GLOM_GLADEDIR "glom.glade", "dialog_groupby_sort_fields");
+    Glib::RefPtr<Gtk::Builder> refXml = Gtk::Builder::create_from_file(Utils::get_glade_file_path("glom_developer.glade"), "dialog_groupby_sort_fields");
     if(refXml)
     {
       refXml->get_widget_derived("dialog_groupby_sort_fields", m_dialog_choose_sort_fields);
@@ -158,7 +160,7 @@ void Dialog_GroupBy::on_button_secondary_fields()
 {
   if(!m_dialog_choose_secondary_fields)
   {
-    Glib::RefPtr<Gnome::Glade::Xml> refXml = Gnome::Glade::Xml::create(GLOM_GLADEDIR "glom.glade", "dialog_groupby_secondary_fields");
+    Glib::RefPtr<Gtk::Builder> refXml = Gtk::Builder::create_from_file(Utils::get_glade_file_path("glom_developer.glade"), "dialog_groupby_secondary_fields");
     if(refXml)
     {
       refXml->get_widget_derived("dialog_groupby_secondary_fields", m_dialog_choose_secondary_fields);
@@ -171,14 +173,14 @@ void Dialog_GroupBy::on_button_secondary_fields()
 
   if(m_dialog_choose_secondary_fields)
   {
-    m_dialog_choose_secondary_fields->set_fields(m_table_name, m_layout_item->m_group_secondary_fields->m_map_items);
+    m_dialog_choose_secondary_fields->set_fields(m_table_name, m_layout_item->m_group_secondary_fields->m_list_items);
 
     const int response = Glom::Utils::dialog_run_with_help(m_dialog_choose_secondary_fields, "dialog_groupby_secondary_fields");
     m_dialog_choose_secondary_fields->hide();
     if(response == Gtk::RESPONSE_OK && m_dialog_choose_secondary_fields->get_modified())
     {
       m_layout_item->m_group_secondary_fields->remove_all_items(); //Free the existing member items.
-      m_layout_item->m_group_secondary_fields->m_map_items = m_dialog_choose_secondary_fields->get_fields();
+      m_layout_item->m_group_secondary_fields->m_list_items = m_dialog_choose_secondary_fields->get_fields();
     }
   }
 
@@ -221,13 +223,16 @@ void Dialog_GroupBy::update_labels()
   Glib::ustring text_secondary_fields;
   if(m_layout_item->m_group_secondary_fields)
   {
-    const LayoutGroup::type_map_items& map_items = m_layout_item->m_group_secondary_fields->m_map_items;
-    for(LayoutGroup::type_map_items::const_iterator iter = map_items.begin(); iter != map_items.end(); ++iter)
+    const LayoutGroup::type_list_items& map_items = m_layout_item->m_group_secondary_fields->m_list_items;
+    for(LayoutGroup::type_list_items::const_iterator iter = map_items.begin(); iter != map_items.end(); ++iter)
     {
-      if(!text_secondary_fields.empty())
-        text_secondary_fields += ", ";
+      if(*iter)
+      {
+        if(!text_secondary_fields.empty())
+          text_secondary_fields += ", ";
 
-      text_secondary_fields += iter->second->get_layout_display_name();
+        text_secondary_fields += (*iter)->get_layout_display_name();
+      }
     }
   }
 
