@@ -21,8 +21,8 @@
 #include <libglom/libglom_config.h> // For GLOM_ENABLE_MAEMO
  
 #include <libglom/connectionpool.h>
-#include <libglom/document/document_glom.h>
-#include <bakery/bakery.h>
+#include <libglom/document/document.h>
+#include <libglom/utils.h>
 //#include <libgdamm/connectionevent.h>
 #include <glibmm/i18n.h>
 
@@ -38,10 +38,6 @@
 # define DATADIR GLOM_SAVE_DATADIR
 #endif
 
-#ifdef GLOM_ENABLE_MAEMO
-#include <hildonmm/note.h>
-#endif
-
 #include <signal.h> //To catch segfaults
 
 #ifndef GLOM_ENABLE_CLIENT_ONLY
@@ -198,7 +194,7 @@ SharedConnection::type_signal_finished SharedConnection::signal_finished()
 void SharedConnection::close()
 {
   if(m_gda_connection)
-    m_gda_connection.clear();
+    m_gda_connection.reset();
 
 
   //Tell the connection pool that we have finished with this connection.
@@ -291,14 +287,20 @@ sharedptr<SharedConnection> ConnectionPool::get_and_connect(std::auto_ptr<Except
   sharedptr<SharedConnection> result(0);
 
   ConnectionPool* connection_pool = ConnectionPool::get_instance();
-  if(connection_pool)
+  if(!connection_pool)
+    return result;
+
+  if(!(connection_pool->m_backend.get()))
   {
-#ifdef GLIBMM_EXCEPTIONS_ENABLED
-    result = connection_pool->connect();
-#else
-    result = connection_pool->connect(error);
-#endif // GLIBMM_EXCEPTIONS_ENABLED
+    std::cerr << "ConnectionPool::get_and_connect(): m_backend is null." << std::endl;
+    return result; //TODO: Return a FAILURE_NO_BACKEND erro?, though that would be tedious.
   }
+  
+#ifdef GLIBMM_EXCEPTIONS_ENABLED
+  result = connection_pool->connect();
+#else
+  result = connection_pool->connect(error);
+#endif // GLIBMM_EXCEPTIONS_ENABLED
 
   return result;
 }
@@ -308,8 +310,10 @@ sharedptr<SharedConnection> ConnectionPool::get_and_connect(std::auto_ptr<Except
 // Store the connection for a few seconds in case it 
 // is immediately requested again, to avoid making a new connection 
 // and introspecting again, which is slow. 
+// TODO: Why aren't these member variables?
 static sharedptr<SharedConnection> connection_cached;
 static sigc::connection connection_cached_timeout_connection;
+static sigc::connection connection_cached_finished_connection;
 
 static bool on_connection_pool_cache_timeout()
 {
@@ -328,15 +332,29 @@ sharedptr<SharedConnection> ConnectionPool::connect()
 sharedptr<SharedConnection> ConnectionPool::connect(std::auto_ptr<ExceptionConnection>& error)
 #endif
 {
+  //Don't try to connect if we don't have a backend to connect to.
+  g_return_val_if_fail(m_backend.get(), sharedptr<SharedConnection>(0));
+
   if(get_ready_to_connect())
   {
+    if(connection_cached)
+    {
+      //Avoid a reconnection immediately after disconnecting:
+      return connection_cached;
+    }
     //If the connection is already open (because it is being used by somebody):
-    if(m_refGdaConnection)
+    else if(m_refGdaConnection)
     {
       sharedptr<SharedConnection> sharedConnection( new SharedConnection(m_refGdaConnection) );
 
       //Ask for notification when the SharedConnection has been finished with:
-      sharedConnection->signal_finished().connect( sigc::mem_fun(*this, &ConnectionPool::on_sharedconnection_finished) );
+      //TODO: Note that we are overwriting the connection to a signal of a
+      //previous sharedconnection here. This can be problematic when
+      //invalidate_connection() is called, because then we don't disconnect
+      //from the signal of the previous instance, and when the signal
+      //handler is called later we might decrement the reference count for
+      //a completely different shared connection.
+      connection_cached_finished_connection = sharedConnection->signal_finished().connect( sigc::mem_fun(*this, &ConnectionPool::on_sharedconnection_finished) );
 
       //Remember that somebody is using it:
       m_sharedconnection_refcount++;
@@ -349,18 +367,12 @@ sharedptr<SharedConnection> ConnectionPool::connect(std::auto_ptr<ExceptionConne
 
       return sharedConnection;
     }
-    else if(connection_cached)
-    {
-      //Avoid a reconnection immediately after disconnecting:
-      return connection_cached;
-    }
     else
     {
 #ifdef GLIBMM_EXCEPTIONS_ENABLED
       std::auto_ptr<ExceptionConnection> error;
 #endif
-      if(m_backend.get())
-        m_refGdaConnection = m_backend->connect(m_database, get_user(), get_password(), error);
+      m_refGdaConnection = m_backend->connect(m_database, get_user(), get_password(), error);
 
       if(!m_refGdaConnection)
       {
@@ -372,9 +384,23 @@ sharedptr<SharedConnection> ConnectionPool::connect(std::auto_ptr<ExceptionConne
       else
       {
         //Allow get_meta_store_data() to succeed:
-        std::cout << "DEBUG: Calling update_meta_store() ..." << std::endl;
-        m_refGdaConnection->update_meta_store();
-        std::cout << "DEBUG: ... update_meta_store() has finished." << std::endl;
+        //Hopefully this (and the update_meta_store_for_table() calls) is all we need.
+        std::cout << "DEBUG: Calling update_meta_store_data_types() ..." << std::endl;
+        m_refGdaConnection->update_meta_store_data_types();
+        std::cout << "DEBUG: ... update_meta_store_data_types() has finished." << std::endl;
+
+        std::cout << "DEBUG: Calling update_meta_store_table_names() ..." << std::endl;
+        try
+        {
+          //update_meta_store_table_names() has been known to throw an exception.
+          //Glom is mostly unusable when it fails, but that's still better than a crash.
+          m_refGdaConnection->update_meta_store_table_names(m_backend->get_public_schema_name());
+        }
+        catch(const Glib::Error& ex)
+        {
+          std::cerr << "update_meta_store_table_names() failed: " << ex.what() << std::endl;
+        }
+        std::cout << "DEBUG: ... update_meta_store_table_names() has finished." << std::endl;
 
         // Connection succeeded
         // Create the fieldtypes member if it has not already been done:
@@ -388,7 +414,9 @@ sharedptr<SharedConnection> ConnectionPool::connect(std::auto_ptr<ExceptionConne
         //to avoid duplicates.
         //TODO: Only advertize if it makes sense for the backend,
         //it does not for sqlite
-        avahi_start_publishing(); //Stopped in the signal_finished handler.
+        Document* document = get_document();
+        if(document && document->get_network_shared())
+          avahi_start_publishing(); //Stopped in the signal_finished handler.
 #endif // !G_OS_WIN32
 #endif // !GLOM_ENABLE_CLIENT_ONLY
 
@@ -439,7 +467,7 @@ void ConnectionPool::set_user(const Glib::ustring& value)
   m_user = value;
 
   //Make sure that connect() makes a new connection:
-  connection_cached.clear();
+  invalidate_connection();
 }
 
 void ConnectionPool::set_password(const Glib::ustring& value)
@@ -447,7 +475,7 @@ void ConnectionPool::set_password(const Glib::ustring& value)
   m_password = value;
   
   //Make sure that connect() makes a new connection:
-  connection_cached.clear();
+  invalidate_connection();
 }
 
 void ConnectionPool::set_database(const Glib::ustring& value)
@@ -455,7 +483,7 @@ void ConnectionPool::set_database(const Glib::ustring& value)
   m_database = value;
 
   //Make sure that connect() makes a new connection:
-  connection_cached.clear();
+  invalidate_connection();
 }
 
 Glib::ustring ConnectionPool::get_user() const
@@ -490,6 +518,15 @@ Glib::ustring ConnectionPool::get_string_find_operator() const
   return m_backend->get_string_find_operator();
 }
 
+void ConnectionPool::invalidate_connection()
+{
+  connection_cached.clear();
+  connection_cached_timeout_connection.disconnect();
+  connection_cached_finished_connection.disconnect();
+  m_refGdaConnection.reset();
+  m_sharedconnection_refcount = 0;
+}
+
 void ConnectionPool::on_sharedconnection_finished()
 {
   //g_warning("ConnectionPool::on_sharedconnection_finished().");
@@ -505,7 +542,7 @@ void ConnectionPool::on_sharedconnection_finished()
     //g_warning("ConnectionPool::on_sharedconnection_finished(): closing GdaConnection");
     m_refGdaConnection->close();
 
-    m_refGdaConnection.clear();
+    m_refGdaConnection.reset();
 
 #ifndef GLOM_ENABLE_CLIENT_ONLY
 #ifndef G_OS_WIN32
@@ -519,7 +556,7 @@ void ConnectionPool::on_sharedconnection_finished()
 }
 
 //static
-bool ConnectionPool::handle_error(bool cerr_only)
+bool ConnectionPool::handle_error_cerr_only()
 {
 #ifdef GLIBMM_EXCEPTIONS_ENABLED
   sharedptr<SharedConnection> sharedconnection = get_and_connect();
@@ -551,25 +588,6 @@ bool ConnectionPool::handle_error(bool cerr_only)
         }
       }
 
-      //For debugging only:
-      //Gtk::Dialog* dialog = 0;
-      //dialog->run(); //Force a crash.
-
-      if(!cerr_only)
-      {
-#ifdef GLOM_ENABLE_MAEMO
-        Hildon::Note dialog(Hildon::NOTE_TYPE_INFORMATION, error_details);
-#else
-        Gtk::MessageDialog dialog(Bakery::App_Gtk::util_bold_message(_("Internal error")), true, Gtk::MESSAGE_WARNING );
-        dialog.set_secondary_text(error_details);
-#endif
-        //TODO: dialog.set_transient_for(*get_application());
-        dialog.run(); //TODO: This segfaults in gtk_window_set_modal() when this method is run a second time, for instance if there are two database errors.
-#ifdef GLOM_CONNECTION_DEBUG
-        std::cout << "debug: after Internal Error dialog run()." << std::endl;
-#endif
-      }
-
       return true; //There really was an error.
     }
   }
@@ -596,9 +614,8 @@ static void on_linux_signal(int signum)
 
   if(signum == SIGSEGV)
   {
-    //TODO: Make this dialog transient for the parent window, 
-    //though this is obviously an unusual case.
-    connection_pool->cleanup(0 /* parent_window */);
+    ConnectionPool::SlotProgress slot_ignored;
+    connection_pool->cleanup(slot_ignored);
 
     //Let GNOME/Ubuntu's crash handler still handle this?
     if(previous_sig_handler)
@@ -608,12 +625,12 @@ static void on_linux_signal(int signum)
   }
 }
 
-bool ConnectionPool::startup(Gtk::Window* parent_window)
+bool ConnectionPool::startup(const SlotProgress& slot_progress, bool network_shared)
 {
   if(!m_backend.get())
     return false;
 
-  if(!m_backend->startup(parent_window))
+  if(!m_backend->startup(slot_progress, network_shared))
     return false;
 
 #ifndef G_OS_WIN32
@@ -628,13 +645,23 @@ bool ConnectionPool::startup(Gtk::Window* parent_window)
   return true;
 }
 
-void ConnectionPool::cleanup(Gtk::Window* parent_window)
+void ConnectionPool::cleanup(const SlotProgress& slot_progress)
 {
+  // Without a valid backend instance we should not state that we are ready to
+  // connect. Fixes crash described in #577821.
+
+  // TODO: Implement checks in set_ready_to_connect() to only set the flag to
+  // "true" when the ConnectionPool instance is in a consistent state
+  // afterwards. Or, have a private set_ready_to_connect() and a public
+  // set_not_ready_to_connect()?
+  set_ready_to_connect(false);
+
   if(m_backend.get())
-    m_backend->cleanup(parent_window);
+    m_backend->cleanup(slot_progress);
+
+  //Make sure that connect() tries to make a new connection:
+  invalidate_connection();
 
-  //Make sure that connect() makes a new connection:
-  connection_cached.clear();
 
 #ifndef G_OS_WIN32
   /* Stop advertising the self-hosting database server via avahi: */
@@ -646,6 +673,15 @@ void ConnectionPool::cleanup(Gtk::Window* parent_window)
   previous_sig_handler = SIG_DFL; /* Arbitrary default */
 }
 
+
+bool ConnectionPool::set_network_shared(const SlotProgress& slot_progress, bool network_shared)
+{
+  if(m_backend.get())
+    return m_backend->set_network_shared(slot_progress, network_shared);
+  else
+    return false;
+}
+
 #ifndef GLOM_ENABLE_CLIENT_ONLY
 #ifdef GLIBMM_EXCEPTIONS_ENABLED
 bool ConnectionPool::add_column(const Glib::ustring& table_name, const sharedptr<const Field>& field)
@@ -674,11 +710,11 @@ bool ConnectionPool::add_column(const Glib::ustring& table_name, const sharedptr
   const bool result = m_backend->add_column(m_refGdaConnection, table_name, field, error);
   if(error.get()) throw *error;
 
-  m_refGdaConnection->update_meta_store_table(table_name);
+  m_refGdaConnection->update_meta_store_table(table_name, m_backend->get_public_schema_name());
 #else
   const bool result = m_backend->add_column(m_refGdaConnection, table_name, field, error);
   if(result)
-    result = m_refGdaConnection->update_meta_store_table(table_name, error);
+    result = m_refGdaConnection->update_meta_store_table(table_name, m_backend->get_public_schema_name(), error);
 #endif
 
   return result;
@@ -711,11 +747,11 @@ bool ConnectionPool::drop_column(const Glib::ustring& table_name, const Glib::us
   const bool result = m_backend->drop_column(m_refGdaConnection, table_name, field_name, error);
   if(error.get()) throw *error;
 
-  m_refGdaConnection->update_meta_store_table(table_name);
+  m_refGdaConnection->update_meta_store_table(table_name, m_backend->get_public_schema_name());
 #else
   const bool result = m_backend->drop_column(m_refGdaConnection, table_name, field_name, error);
   if(result)
-    result = m_refGdaConnection->update_meta_store_table(table_name, error);
+    result = m_refGdaConnection->update_meta_store_table(table_name, m_backend->get_public_schema_name(), error);
 #endif
 
   return result;
@@ -727,8 +763,8 @@ bool ConnectionPool::change_column(const Glib::ustring& table_name, const shared
 bool ConnectionPool::change_column(const Glib::ustring& table_name, const sharedptr<const Field>& field_old, const sharedptr<const Field>& field, std::auto_ptr<Glib::Error>& error)
 #endif
 {
-  type_vecConstFields old_fields(1, field_old);
-  type_vecConstFields new_fields(1, field);
+  type_vec_const_fields old_fields(1, field_old);
+  type_vec_const_fields new_fields(1, field);
 
 #ifdef GLIBMM_EXCEPTIONS_ENABLED
   return change_columns(table_name, old_fields, new_fields);
@@ -738,9 +774,9 @@ bool ConnectionPool::change_column(const Glib::ustring& table_name, const shared
 }
 
 #ifdef GLIBMM_EXCEPTIONS_ENABLED
-bool ConnectionPool::change_columns(const Glib::ustring& table_name, const type_vecConstFields& old_fields, const type_vecConstFields& new_fields)
+bool ConnectionPool::change_columns(const Glib::ustring& table_name, const type_vec_const_fields& old_fields, const type_vec_const_fields& new_fields)
 #else
-bool ConnectionPool::change_columns(const Glib::ustring& table_name, const type_vecConstFields& old_fields, const type_vecConstFields& new_fields, std::auto_ptr<Glib::Error>& error)
+bool ConnectionPool::change_columns(const Glib::ustring& table_name, const type_vec_const_fields& old_fields, const type_vec_const_fields& new_fields, std::auto_ptr<Glib::Error>& error)
 #endif
 {
   sharedptr<SharedConnection> conn;
@@ -764,71 +800,27 @@ bool ConnectionPool::change_columns(const Glib::ustring& table_name, const type_
   const bool result = m_backend->change_columns(m_refGdaConnection, table_name, old_fields, new_fields, error);
   if(error.get()) throw *error;
 
-  m_refGdaConnection->update_meta_store_table(table_name);
+  m_refGdaConnection->update_meta_store_table(table_name, m_backend->get_public_schema_name());
 #else
   const bool result = m_backend->change_columns(m_refGdaConnection, table_name, old_fields, new_fields, error);
   if(result)
-    result = m_refGdaConnection->update_meta_store_table(table_name, error);
+    result = m_refGdaConnection->update_meta_store_table(table_name, m_backend->get_public_schema_name(), error);
 #endif
 
   return result;
 }
 #endif // !GLOM_ENABLE_CLIENT_ONLY
 
-bool ConnectionPool::initialize(Gtk::Window* parent_window)
+ConnectionPool::InitErrors ConnectionPool::initialize(const SlotProgress& slot_progress, bool network_shared)
 {
   if(m_backend.get())
-    return m_backend->initialize(parent_window, get_user(), get_password());
+    return m_backend->initialize(slot_progress, get_user(), get_password(), network_shared);
   else
-    return false;
+    return Backend::INITERROR_OTHER;
 }
 
-bool ConnectionPool::check_user_is_not_root()
-{
-  Glib::ustring message;
-#ifdef G_OS_WIN32
-  try
-  {
-    if(pgwin32_is_admin())
-    {
-      message = _("You seem to be running Glom as a user with administrator privileges. Glom may not be run with such privileges for security reasons.\nPlease login to your system as a normal user.");
-    }
-  }
-  catch(const std::runtime_error& ex)
-  {
-    message = ex.what();
-  }
-#else
-  //std::cout << "ConnectionPool::check_user_is_not_root(): geteuid()=" << geteuid() << ", getgid()=" << getgid() << std::endl;
-
-  //This is very linux-specific. We should ifdef this out for other platforms.
-  if(geteuid() == 0)
-  {
-    //Warn the user:
-    message = _("You seem to be running Glom as root. Glom may not be run as root.\nPlease login to your system as a normal user.");
-  }
-#endif
-
-  if(!message.empty())
-  {
-#ifndef GLOM_ENABLE_MAEMO
-    Gtk::MessageDialog dialog(Bakery::App_Gtk::util_bold_message(_("Running As Root")), true /* use_markup */, Gtk::MESSAGE_ERROR, Gtk::BUTTONS_OK, true /* modal */);
-    dialog.set_secondary_text(message);
-    dialog.run();
-#else
-    Hildon::Note note(Hildon::NOTE_TYPE_INFORMATION, message);
-    note.run();
-#endif
-
-    return false; /* Is root. Bad. */
-  }
-
-  return true; /* Not root. It's OK. */
-}
-
-
 #ifndef GLOM_ENABLE_CLIENT_ONLY
-Document_Glom* ConnectionPool::get_document()
+Document* ConnectionPool::get_document()
 {
   if(!m_slot_get_document)
   {
@@ -849,7 +841,7 @@ EpcContents* ConnectionPool::on_publisher_document_requested(EpcPublisher* /* pu
   if(!connection_pool)
     return 0;
 
-  const Document_Glom* document = connection_pool->get_document();
+  const Document* document = connection_pool->get_document();
   if(!document)
     return 0;
 
@@ -897,45 +889,34 @@ gboolean ConnectionPool::on_publisher_document_authentication(EpcAuthContext* co
 void ConnectionPool::on_epc_progress_begin(const gchar* /* title */, gpointer user_data)
 {
   //We ignore the title parameter because there is no way that libepc could know what Glom wants to say.
- 
+  
   ConnectionPool* connection_pool = (ConnectionPool*)user_data;
-
-  //Create the dialog:
-  if(connection_pool->m_dialog_epc_progress)
-  {
-    delete connection_pool->m_dialog_epc_progress;
-    connection_pool->m_dialog_epc_progress = 0;
-  }
-
-  Gtk::MessageDialog* message_dialog = new Gtk::MessageDialog(Bakery::App_Gtk::util_bold_message(_("Glom: Generating Encryption Certificates")), true, Gtk::MESSAGE_INFO);
-  message_dialog->set_secondary_text(_("Please wait while Glom prepares your system for publishing over the network."));
-  message_dialog->show();
-
-  connection_pool->m_dialog_epc_progress = message_dialog; 
+  if(connection_pool)
+    connection_pool->m_epc_slot_begin();
 }
 
-void ConnectionPool::on_epc_progress_update(gdouble /* progress */, const gchar* /* message */, gpointer /* user_data */)
+void ConnectionPool::on_epc_progress_update(gdouble /* progress */, const gchar* /* message */, gpointer user_data)
 {
   //We ignore the title parameter because there is no way that libepc could know what Glom wants to say.
   //TODO: Show the progress in a ProgressBar.
 
-  //ConnectionPool* connection_pool = (ConnectionPool*)user_data;
-
-  //Allow GTK+ to process events, so that the UI is responsive:
-  while(Gtk::Main::events_pending())
-   Gtk::Main::iteration();
+  ConnectionPool* connection_pool = (ConnectionPool*)user_data;
+  if(connection_pool)
+    connection_pool->m_epc_slot_progress();
 }
 
 void ConnectionPool::on_epc_progress_end(gpointer user_data)
 {
   ConnectionPool* connection_pool = (ConnectionPool*)user_data;
+  if(connection_pool)
+    connection_pool->m_epc_slot_done();
+}
 
-  //Delete the dialog:
-  if(connection_pool->m_dialog_epc_progress)
-  {
-    delete connection_pool->m_dialog_epc_progress;
-    connection_pool->m_dialog_epc_progress = 0;
-  }
+void ConnectionPool::set_avahi_publish_callbacks(const type_void_slot& slot_begin, const type_void_slot& slot_progress, const type_void_slot& slot_done)
+{
+  m_epc_slot_begin = slot_begin;
+  m_epc_slot_progress = slot_progress;
+  m_epc_slot_done = slot_done; 
 }
 
 
@@ -954,7 +935,7 @@ void ConnectionPool::avahi_start_publishing()
 #endif
   
   //Publish the document contents over HTTPS (discoverable via avahi):
-  const Document_Glom* document = get_document();
+  const Document* document = get_document();
   if(!document)
     return;
 
@@ -1012,7 +993,7 @@ void ConnectionPool::avahi_stop_publishing()
   epc_publisher_quit(m_epc_publisher);
 #endif // !G_OS_WIN32
   g_object_unref(m_epc_publisher);
-  m_epc_publisher = NULL;
+  m_epc_publisher = 0;
 }
 #endif // !G_OS_WIN32
 
