@@ -18,17 +18,16 @@
  * Boston, MA 02111-1307, USA.
  */
 
-#include "config.h" // For GLOM_ENABLE_MAEMO
+#include <libglom/libglom_config.h> // For GLOM_ENABLE_MAEMO
 
-#include <glom/libglom/utils.h>
-#include <glom/libglom/connectionpool.h>
-#include <glom/libglom/data_structure/layout/report_parts/layoutitem_fieldsummary.h>
-#include <glom/libglom/data_structure/glomconversions.h>
+#include <libglom/utils.h>
+#include <libglom/connectionpool.h>
+#include <libglom/data_structure/layout/report_parts/layoutitem_fieldsummary.h>
+#include <libglom/data_structure/glomconversions.h>
 
 #include <glibmm/i18n.h>
-#include <gtkmm/messagedialog.h>
 
-#include <gio/gio.h> // For g_app_info_launch_default_for_uri
+#include <giomm.h>
 
 #ifdef GLOM_ENABLE_MAEMO
 #include <hildonmm/note.h>
@@ -47,51 +46,6 @@
 
 #include <stack>
 
-#ifdef GLOM_ENABLE_MAEMO
-//We use different spacings on Maemo because the screen is smaller:
-const unsigned int Glom::Utils::DEFAULT_SPACING_LARGE =  1;
-const unsigned int Glom::Utils::DEFAULT_SPACING_SMALL =  1;
-#else
-const unsigned int Glom::Utils::DEFAULT_SPACING_LARGE = 12;
-const unsigned int Glom::Utils::DEFAULT_SPACING_SMALL =  6;
-#endif //GLOM_ENABLE_MAEMO
-
-namespace
-{
-
-// Basically copied from libgnome (gnome-help.c, Copyright (C) 2001 Sid Vicious
-// Copyright (C) 2001 Jonathan Blandford <jrb@alum.mit.edu>), but C++ified
-std::string locate_help_file(const std::string& path, const std::string& doc_name)
-{
-  // g_get_language_names seems not to be wrapped by glibmm
-  const char* const* lang_list = g_get_language_names ();
-
-  for(unsigned int j = 0; lang_list[j] != NULL; ++j)
-  {
-    const char* lang = lang_list[j];
-
-    /* This has to be a valid language AND a language with
-     * no encoding postfix.  The language will come up without
-     * encoding next. */
-    if(lang == NULL || strchr(lang, '.') != NULL)
-      continue;
-
-    const char* exts[] = { "", ".xml", ".docbook", ".sgml", ".html", NULL };
-    for(unsigned i = 0; exts[i] != NULL; ++i)
-    {
-      std::string name = doc_name + exts[i];
-      std::string full = Glib::build_filename(path, Glib::build_filename(lang, name));
-
-      if(Glib::file_test(full, Glib::FILE_TEST_EXISTS))
-        return full;
-    }
-  }
-
-  return std::string();
-}
-
-}
-
 namespace Glom
 {
 
@@ -133,7 +87,7 @@ public:
     return (element->get_relationship_name() == m_relationship_name) && (element->get_related_relationship_name() == m_related_relationship_name);
   }
 
-protected:
+private:
   Glib::ustring m_relationship_name, m_related_relationship_name;
 };
 
@@ -468,9 +422,13 @@ Utils::type_list_values_with_second Utils::get_choice_values(const sharedptr<con
 #else
   std::auto_ptr<ExceptionConnection> conn_error;
   sharedptr<SharedConnection> connection = ConnectionPool::get_instance()->connect(conn_error);
-  if(conn_error.get() != NULL) return list_values;
+  if(conn_error.get())
+    return list_values;
 #endif
 
+  if(!connection)
+    return list_values;
+
   //std::cout << "get_choice_values: Executing SQL: " << sql_query << std::endl;
 #ifdef GLIBMM_EXCEPTIONS_ENABLED
   Glib::RefPtr<Gnome::Gda::DataModel> datamodel = connection->get_gda_connection()->statement_execute_select(sql_query);
@@ -639,11 +597,11 @@ Glib::ustring Utils::title_from_string(const Glib::ustring& text)
   return result;
 }
 
-Utils::type_vecStrings Utils::string_separate(const Glib::ustring& str, const Glib::ustring& separator, bool ignore_quoted_separator)
+Utils::type_vec_strings Utils::string_separate(const Glib::ustring& str, const Glib::ustring& separator, bool ignore_quoted_separator)
 {
   //std::cout << "Utils::string_separate(): separator=" << separator << std::endl;
 
-  type_vecStrings result;
+  type_vec_strings result;
 
   const Glib::ustring::size_type size = str.size();
   const Glib::ustring::size_type size_separator = separator.size();
@@ -816,124 +774,29 @@ Glib::ustring Utils::string_remove_suffix(const Glib::ustring& str, const Glib::
   return str;
 }
 
-/* Run dialog and response on Help if appropriate */
 
-int Utils::dialog_run_with_help(Gtk::Dialog* dialog, const Glib::ustring& id)
+
+bool Utils::file_exists(const Glib::ustring& uri)
 {
-  int result = dialog->run();
-  while (result == Gtk::RESPONSE_HELP)
+  //Check whether file exists already:
   {
-    show_help(id);
-    result = dialog->run();
-  }
+    // Try to examine the input file.
+    Glib::RefPtr<Gio::File> file = Gio::File::create_for_uri(uri);
 
-  dialog->hide();
-  return result;
-}
-
-/*
- * Help::show_help(const std::string& id)
- *
- * Launch a help browser with the glom help and load the given id if given
- * If the help cannot be found an error dialog will be shown
- */
-
-void Utils::show_help(const Glib::ustring& id)
-{
-  // TODO_maemo: Show help on maemo by some other means
-#ifndef GLOM_ENABLE_MAEMO
-  GError* err = 0;
-  const gchar* pId;
-  if(id.length())
-  {
-    pId = id.c_str();
-  }
-  else
-  {
-    pId = 0;
-  }
-
-  try
-  {
-    const char* path = DATADIR "/gnome/help/glom";
-    std::string help_file = locate_help_file(path, "glom.xml");
-    if(help_file.empty())
+#ifdef GLIBMM_EXCEPTIONS_ENABLED
+    try
     {
-      throw std::runtime_error(_("No help file available"));
+      return file->query_exists();
     }
-    else
+    catch(const Gio::Error& /* ex */)
     {
-      std::string uri = "ghelp:" + help_file;
-      if(pId) { uri += "?"; uri += pId; }
-
-      // g_app_info_launch_default_for_uri seems not to be wrapped by giomm
-      if(!g_app_info_launch_default_for_uri(uri.c_str(), NULL, &err))
-      {
-        std::string message(err->message);
-        g_error_free(err);
-        throw std::runtime_error(message);
-      }
+      return false; //Something went wrong. It does not exist.
     }
-  }
-  catch(const std::exception& ex)
-  {
-    const Glib::ustring message = _("Could not display help: ") + Glib::ustring(ex.what());
-    Gtk::MessageDialog dialog(message, false, Gtk::MESSAGE_ERROR);
-    dialog.run();
-  }
-#endif
-}
-
-void Utils::show_ok_dialog(const Glib::ustring& title, const Glib::ustring& message, Gtk::Window* parent, Gtk::MessageType message_type)
-{
-#ifdef GLOM_ENABLE_MAEMO
-  // TODO_maemo: Map message_type to a senseful stock_id?
-  Hildon::Note dialog(Hildon::NOTE_TYPE_INFORMATION, parent, message);
 #else
-  Gtk::MessageDialog dialog("<b>" + title + "</b>", true /* markup */, message_type, Gtk::BUTTONS_OK);
-  dialog.set_secondary_text(message);
-  if(parent)
-    dialog.set_transient_for(*parent);
+      std::auto_ptr<Gio::Error> error;
+      retrun file->query_exists(error);
 #endif
-
-  dialog.run();
-}
-
-void Utils::show_ok_dialog(const Glib::ustring& title, const Glib::ustring& message, Gtk::Window& parent, Gtk::MessageType message_type)
-{
-  show_ok_dialog(title, message, &parent, message_type);
-}
-
-namespace
-{
-
-static void on_window_hide(Glib::RefPtr<Glib::MainLoop> main_loop, sigc::connection handler_connection)
-{
-  handler_connection.disconnect(); //This should release a main_loop reference.
-  main_loop->quit();
-
-  //main_loop should be destroyed soon, because nothing else is using it.
-}
-
-} //anonymous namespace.
-
-void Utils::show_window_until_hide(Gtk::Window* window)
-{
-  if(!window)
-    return;
-
-  Glib::RefPtr<Glib::MainLoop> main_loop = Glib::MainLoop::create(false /* not running */);
-
-  //Stop the main_loop when the window is hidden:
-  sigc::connection handler_connection; //TODO: There seems to be a crash if this is on the same line.
-  handler_connection = window->signal_hide().connect( 
-    sigc::bind(
-      sigc::ptr_fun(&on_window_hide),
-      main_loop, handler_connection
-    ) );
-  
-  window->show();
-  main_loop->run(); //Run and block until it is stopped by the hide signal handler.
+  }
 }
 
 
