@@ -21,14 +21,14 @@
 #ifndef BOX_DATA_DETAILS_H
 #define BOX_DATA_DETAILS_H
 
-#include "config.h" // For GLOM_ENABLE_CLIENT_ONLY
+#include <libglom/libglom_config.h> // For GLOM_ENABLE_CLIENT_ONLY
 
 #include "box_data.h"
-//#include "box_data_list_related.h"
+//#include <glom/mode_data/box_data_list_related.h>
 #include "flowtablewithfields.h"
-#include "../utility_widgets/placeholder.h"
+#include <glom/utility_widgets/placeholder.h>
 #ifndef GLOM_ENABLE_CLIENT_ONLY
-#include "../utility_widgets/dragbar.h"
+#include <glom/utility_widgets/layouttoolbar.h>
 #endif
 
 namespace Glom
@@ -40,7 +40,7 @@ public:
   Box_Data_Details(bool bWithNavButtons = true);
   virtual ~Box_Data_Details();
 
-  virtual bool init_db_details(const FoundSet& found_set, const Gnome::Gda::Value& primary_key_value);
+  virtual bool init_db_details(const FoundSet& found_set, const Glib::ustring& layout_platform, const Gnome::Gda::Value& primary_key_value);
   virtual bool refresh_data_from_database_with_primary_key(const Gnome::Gda::Value& primary_key_value);
   virtual bool refresh_data_from_database_blank();
 
@@ -63,6 +63,10 @@ public:
   typedef sigc::signal<void, const Glib::ustring&, Gnome::Gda::Value> type_signal_requested_related_details;
   type_signal_requested_related_details signal_requested_related_details();
 
+#ifndef GLOM_ENABLE_CLIENT_ONLY
+  void show_layout_toolbar(bool show = true);
+#endif
+
 protected:
 
 
@@ -130,7 +134,7 @@ protected:
   Gtk::Button m_Button_New;
   Gtk::Button m_Button_Del;
 #ifndef GLOM_ENABLE_CLIENT_ONLY
-  DragBar m_Dragbar;
+  LayoutToolbar m_Dragbar;
 #endif
 
   /*
