@@ -21,7 +21,7 @@
 #include "dialog_layout_calendar_related.h"
 #include "dialog_choose_field.h"
 #include "../layout_item_dialogs/dialog_field_layout.h"
-#include <bakery/App/App_Gtk.h> //For util_bold_message().
+#include <libglom/utils.h> //For bold_message()).
 
 //#include <libgnome/gnome-i18n.h>
 #include <gtkmm/togglebutton.h>
@@ -30,8 +30,8 @@
 namespace Glom
 {
 
-Dialog_Layout_Calendar_Related::Dialog_Layout_Calendar_Related(BaseObjectType* cobject, const Glib::RefPtr<Gnome::Glade::Xml>& refGlade)
-: Dialog_Layout_List(cobject, refGlade),
+Dialog_Layout_Calendar_Related::Dialog_Layout_Calendar_Related(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& builder)
+: Dialog_Layout_List(cobject, builder),
   m_combo_relationship(0),
   m_checkbutton_show_child_relationships(0),
   m_radio_navigation_automatic(0),
@@ -45,24 +45,24 @@ Dialog_Layout_Calendar_Related::Dialog_Layout_Calendar_Related(BaseObjectType* c
   m_box_related_table_widgets->show();
   m_box_related_navigation->show();
 
-  refGlade->get_widget_derived("combo_relationship_name", m_combo_relationship);
+  builder->get_widget_derived("combo_relationship_name", m_combo_relationship);
   m_combo_relationship->signal_changed().connect(sigc::mem_fun(*this, &Dialog_Layout_Calendar_Related::on_combo_relationship_changed));
 
-  refGlade->get_widget("checkbutton_show_child_relationships", m_checkbutton_show_child_relationships);
+  builder->get_widget("checkbutton_show_child_relationships", m_checkbutton_show_child_relationships);
   m_checkbutton_show_child_relationships->signal_toggled().connect(sigc::mem_fun(*this, &Dialog_Layout_Calendar_Related::on_checkbutton_show_child_relationships));
 
   
 
-  refGlade->get_widget("radiobutton_navigation_automatic", m_radio_navigation_automatic);
-  refGlade->get_widget("label_navigation_automatic", m_label_navigation_automatic);
+  builder->get_widget("radiobutton_navigation_automatic", m_radio_navigation_automatic);
+  builder->get_widget("label_navigation_automatic", m_label_navigation_automatic);
   make_sensitivity_depend_on_toggle_button(*m_radio_navigation_automatic, *m_label_navigation_automatic);
 
-  refGlade->get_widget("radiobutton_navigation_specify", m_radio_navigation_specify);
-  refGlade->get_widget_derived("combobox_navigation_specify", m_combo_navigation_specify);
+  builder->get_widget("radiobutton_navigation_specify", m_radio_navigation_specify);
+  builder->get_widget_derived("combobox_navigation_specify", m_combo_navigation_specify);
   make_sensitivity_depend_on_toggle_button(*m_radio_navigation_specify, *m_combo_navigation_specify);
   m_combo_navigation_specify->signal_changed().connect(sigc::mem_fun(*this, &Dialog_Layout_Calendar_Related::on_combo_navigation_specific_changed));
 
-  refGlade->get_widget_derived("combobox_date_field", m_combobox_date_field);
+  builder->get_widget_derived("combobox_date_field", m_combobox_date_field);
   m_combobox_date_field->signal_changed().connect(sigc::mem_fun(*this, &Dialog_Layout_Calendar_Related::on_combo_date_field_changed));
 
   
@@ -73,7 +73,7 @@ Dialog_Layout_Calendar_Related::Dialog_Layout_Calendar_Related(BaseObjectType* c
   //The base class hid this, but we do want it here:
   //(We share one glade definition for several dialogs.)
   Gtk::Frame* box_calendar = 0;
-  refGlade->get_widget("frame_calendar", box_calendar); 
+  builder->get_widget("frame_calendar", box_calendar); 
   box_calendar->show();
   
   //This entry must be in the Glade file, because it's used by the base class,
@@ -90,7 +90,7 @@ Dialog_Layout_Calendar_Related::~Dialog_Layout_Calendar_Related()
 }
 
 
-void Dialog_Layout_Calendar_Related::set_document(const Glib::ustring& layout, const Glib::ustring& layout_platform, Document_Glom* document, const sharedptr<const LayoutItem_CalendarPortal>& portal)
+void Dialog_Layout_Calendar_Related::set_document(const Glib::ustring& layout, const Glib::ustring& layout_platform, Document* document, const sharedptr<const LayoutItem_CalendarPortal>& portal)
 {
   m_portal = glom_sharedptr_clone(portal);
   
@@ -101,7 +101,7 @@ void Dialog_Layout_Calendar_Related::set_document(const Glib::ustring& layout, c
   set_document(layout, layout_platform, document, from_table);
 }
 
-void Dialog_Layout_Calendar_Related::set_document(const Glib::ustring& layout_name, const Glib::ustring& layout_platform, Document_Glom* document, const Glib::ustring& from_table)
+void Dialog_Layout_Calendar_Related::set_document(const Glib::ustring& layout_name, const Glib::ustring& layout_platform, Document* document, const Glib::ustring& from_table)
 {
   if(!m_portal)
   {
@@ -124,7 +124,7 @@ void Dialog_Layout_Calendar_Related::update_ui(bool including_relationship_list)
   const Glib::ustring related_table_name = m_portal->get_table_used(Glib::ustring() /* parent table - not relevant*/);
 
   //Update the tree models from the document
-  Document_Glom* document = get_document();
+  Document* document = get_document();
   if(document)
   {
     //Fill the relationships combo:
@@ -156,7 +156,7 @@ void Dialog_Layout_Calendar_Related::update_ui(bool including_relationship_list)
     //sharedptr<LayoutItem_CalendarPortal> portal_temp = m_portal;
     m_combo_relationship->set_selected_relationship(m_portal->get_relationship(), m_portal->get_related_relationship()); 
 
-    Document_Glom::type_list_layout_groups mapGroups;
+    Document::type_list_layout_groups mapGroups;
     if(m_portal)
     {
       mapGroups.push_back(m_portal);
@@ -168,7 +168,7 @@ void Dialog_Layout_Calendar_Related::update_ui(bool including_relationship_list)
 
     m_model_items->clear();
 
-    for(Document_Glom::type_list_layout_groups::const_iterator iter = mapGroups.begin(); iter != mapGroups.end(); ++iter)
+    for(Document::type_list_layout_groups::const_iterator iter = mapGroups.begin(); iter != mapGroups.end(); ++iter)
     {
       sharedptr<const LayoutGroup> group = *iter;
       sharedptr<const LayoutGroup> portal = sharedptr<const LayoutItem_CalendarPortal>::cast_dynamic(group);
@@ -194,17 +194,14 @@ void Dialog_Layout_Calendar_Related::update_ui(bool including_relationship_list)
   }
 
   //Show the navigation information:
-  //const Document_Glom::type_vecRelationships vecRelationships = document->get_relationships(m_portal->get_relationship()->get_from_table());
+  //const Document::type_vec_relationships vecRelationships = document->get_relationships(m_portal->get_relationship()->get_from_table());
   m_combo_navigation_specify->set_relationships(document, related_table_name, true /* show related relationships */, false /* don't show parent table */); //TODO: Don't show the hidden tables, and don't show relationships that are not used by any fields.
   //m_combo_navigation_specify->set_display_parent_table(""); //This would be superfluous, and a bit confusing.
 
   bool navigation_is_automatic = false;
-  bool navigation_specific_main = false;
-  sharedptr<UsesRelationship> navrel = m_portal->get_navigation_relationship_specific(navigation_specific_main);
-  if(navigation_specific_main)
-    m_combo_navigation_specify->set_selected_parent_table(related_table_name);
-  else if(navrel)
+  if(m_portal->get_navigation_type() == LayoutItem_Portal::NAVIGATION_SPECIFIC)
   {
+    sharedptr<UsesRelationship> navrel = m_portal->get_navigation_relationship_specific();
     //std::cout << "debug navrel=" << navrel->get_relationship()->get_name() << std::endl;
     m_combo_navigation_specify->set_selected_relationship(navrel->get_relationship(), navrel->get_related_relationship());
   }
@@ -227,7 +224,7 @@ void Dialog_Layout_Calendar_Related::update_ui(bool including_relationship_list)
   bool navigation_automatic_main = false;
   relationship_navigation_automatic = get_portal_navigation_relationship_automatic(m_portal, navigation_automatic_main);
   Glib::ustring automatic_navigation_description;
-  
+
   if(navigation_automatic_main)
     automatic_navigation_description = m_portal->get_relationship_name_used();
   else if(relationship_navigation_automatic)
@@ -269,7 +266,7 @@ void Dialog_Layout_Calendar_Related::save_to_document()
     //Get the data from the TreeView and store it in the document:
 
     //Get the groups and their fields:
-    Document_Glom::type_list_layout_groups mapGroups;
+    Document::type_list_layout_groups mapGroups;
 
     //Add the fields to the portal:
     //The code that created this dialog must read m_portal back out again.
@@ -295,19 +292,19 @@ void Dialog_Layout_Calendar_Related::save_to_document()
       sharedptr<Relationship> rel, rel_related;
       rel = m_combo_navigation_specify->get_selected_relationship(rel_related);
 
-      bool specify_main = (!rel && !rel_related);
       sharedptr<UsesRelationship> uses_rel = sharedptr<UsesRelationship>::create();
       uses_rel->set_relationship(rel);
       uses_rel->set_related_relationship(rel_related);
 
-      m_portal->set_navigation_relationship_specific(specify_main, uses_rel);
+      if (rel || rel_related)
+        m_portal->set_navigation_relationship_specific(uses_rel);
       //std::cout << "debug99 main=specify_main" << ", relationship=" << (rel ? rel->get_name() : "none") << std::endl;
     }
     else
     {
       //std::cout << "debug: set_navigation_relationship_specific(false, none)" << std::endl;
       sharedptr<UsesRelationship> none;
-      m_portal->set_navigation_relationship_specific(false, none);
+      m_portal->set_navigation_relationship_specific(none);
     }
     
     m_portal->set_date_field( m_combobox_date_field->get_selected_field() );
