@@ -20,6 +20,8 @@
 
 #include "dialog_fielddefinition.h"
 #include "dialog_fieldcalculation.h"
+#include <glom/glade_utils.h>
+#include <glom/utils_ui.h>
 #include "../../box_db_table.h"
 //#include <libgnome/gnome-i18n.h>
 #include <glibmm/i18n.h>
@@ -27,37 +29,37 @@
 namespace Glom
 {
 
-Dialog_FieldDefinition::Dialog_FieldDefinition(BaseObjectType* cobject, const Glib::RefPtr<Gnome::Glade::Xml>& refGlade)
-: Dialog_Properties(cobject, refGlade),
+Dialog_FieldDefinition::Dialog_FieldDefinition(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& builder)
+: Dialog_Properties(cobject, builder),
   m_pDataWidget_DefaultValueSimple(0),
   m_box_formatting_placeholder(0),
   m_box_formatting(0)
 {
-  refGlade->get_widget_derived("combobox_type", m_pCombo_Type);
+  builder->get_widget_derived("combobox_type", m_pCombo_Type);
 
-  refGlade->get_widget("entry_name", m_pEntry_Name);
-  refGlade->get_widget("entry_title", m_pEntry_Title);
+  builder->get_widget("entry_name", m_pEntry_Name);
+  builder->get_widget("entry_title", m_pEntry_Title);
 
-  refGlade->get_widget("checkbutton_unique",  m_pCheck_Unique);
-  refGlade->get_widget("checkbutton_primarykey",  m_pCheck_PrimaryKey);
-  refGlade->get_widget("checkbutton_autoincrement",  m_pCheck_AutoIncrement);  
+  builder->get_widget("checkbutton_unique",  m_pCheck_Unique);
+  builder->get_widget("checkbutton_primarykey",  m_pCheck_PrimaryKey);
+  builder->get_widget("checkbutton_autoincrement",  m_pCheck_AutoIncrement);  
 
-  refGlade->get_widget("hbox_default_value_simple",  m_pBox_DefaultValueSimple);
+  builder->get_widget("hbox_default_value_simple",  m_pBox_DefaultValueSimple);
 
-  refGlade->get_widget("box_default_value",  m_pBox_ValueTab);
+  builder->get_widget("box_default_value",  m_pBox_ValueTab);
 
-  refGlade->get_widget("radiobutton_userentry",  m_pRadio_UserEntry);
-  refGlade->get_widget("alignment_userentry",  m_pAlignment_UserEntry);
+  builder->get_widget("radiobutton_userentry",  m_pRadio_UserEntry);
+  builder->get_widget("alignment_userentry",  m_pAlignment_UserEntry);
 
-  refGlade->get_widget("checkbutton_lookup",  m_pCheck_Lookup);
-  refGlade->get_widget("table_lookup",  m_pTable_Lookup);
-  refGlade->get_widget_derived("combobox_lookup_relationship",  m_pCombo_LookupRelationship);
-  refGlade->get_widget_derived("combobox_lookup_field",  m_pCombo_LookupField);
+  builder->get_widget("checkbutton_lookup",  m_pCheck_Lookup);
+  builder->get_widget("table_lookup",  m_pTable_Lookup);
+  builder->get_widget_derived("combobox_lookup_relationship",  m_pCombo_LookupRelationship);
+  builder->get_widget_derived("combobox_lookup_field",  m_pCombo_LookupField);
 
-  refGlade->get_widget("radiobutton_calculate",  m_pRadio_Calculate);
-  refGlade->get_widget("alignment_calculate",  m_pAlignment_Calculate);
-  refGlade->get_widget("textview_calculate",  m_pTextView_Calculation);
-  refGlade->get_widget("button_edit_calculation",  m_pButton_EditCalculation);
+  builder->get_widget("radiobutton_calculate",  m_pRadio_Calculate);
+  builder->get_widget("alignment_calculate",  m_pAlignment_Calculate);
+  builder->get_widget("textview_calculate",  m_pTextView_Calculation);
+  builder->get_widget("button_edit_calculation",  m_pButton_EditCalculation);
 
   //Connect signals:
   m_pCombo_Type->signal_changed().connect( sigc::mem_fun(*this, &Dialog_FieldDefinition::on_combo_type_changed) );
@@ -79,15 +81,15 @@ Dialog_FieldDefinition::Dialog_FieldDefinition(BaseObjectType* cobject, const Gl
 
   //Formatting:
   //Get the place to put the Formatting stuff:
-  refGlade->get_widget("box_formatting_placeholder", m_box_formatting_placeholder);
+  builder->get_widget("box_formatting_placeholder", m_box_formatting_placeholder);
 
   //Get the formatting stuff:
   try
   {
-    Glib::RefPtr<Gnome::Glade::Xml> refXmlFormatting = Gnome::Glade::Xml::create(GLOM_GLADEDIR "glom.glade", "box_formatting");
+    Glib::RefPtr<Gtk::Builder> refXmlFormatting = Gtk::Builder::create_from_file(Utils::get_glade_file_path("glom_developer.glade"), "box_formatting");
     refXmlFormatting->get_widget_derived("box_formatting", m_box_formatting);
   }
-  catch(const Gnome::Glade::XmlError& ex)
+  catch(const Gtk::BuilderError& ex)
   {
     std::cerr << ex.what() << std::endl;
   }
@@ -171,10 +173,10 @@ void Dialog_FieldDefinition::set_field(const sharedptr<const Field>& field, cons
   on_check_lookup_toggled();
 
   //Fill the lookup relationships combo:
-  Document_Glom* document = dynamic_cast<Document_Glom*>(get_document());
+  Document* document = dynamic_cast<Document*>(get_document());
   if(document)
   {
-    const Document_Glom::type_vecRelationships vecRelationships = document->get_relationships(table_name);
+    const Document::type_vec_relationships vecRelationships = document->get_relationships(table_name);
     m_pCombo_LookupRelationship->set_relationships(vecRelationships);
   }
 
@@ -200,7 +202,9 @@ void Dialog_FieldDefinition::set_field(const sharedptr<const Field>& field, cons
 
   on_check_lookup_toggled();
 
+  //std::cout << "debug: dialog_fielddefinition.c:: m_pTextView_Calculation.gobj() gtype = " << G_OBJECT_TYPE_NAME(m_pTextView_Calculation->gobj()) << std::endl;
   m_pTextView_Calculation->get_buffer()->set_text(calculation);
+  //std::cout << "  debug: dialog_fielddefinition.c:: after get_buffer()" << std::endl;
 
   m_pEntry_Title->set_text(field->get_title());
 
@@ -216,7 +220,10 @@ void Dialog_FieldDefinition::set_field(const sharedptr<const Field>& field, cons
 sharedptr<Field> Dialog_FieldDefinition::get_field() const
 {
   sharedptr<Field> field = glom_sharedptr_clone(m_Field); //Start with the old details, to preserve anything that is not in our UI.
-
+  // const_cast is necessary and save here for the window (jhs)
+  sharedptr<SharedConnection> sharedcnc = connect_to_server(const_cast<Dialog_FieldDefinition*>(this));
+  Glib::RefPtr<Gnome::Gda::Connection> cnc = sharedcnc->get_gda_connection();
+  
   //Get the field info from the widgets:
 
   Glib::RefPtr<Gnome::Gda::Column> fieldInfo = field->get_field_info(); //Preserve previous information.
@@ -225,8 +232,6 @@ sharedptr<Field> Dialog_FieldDefinition::get_field() const
 
   fieldInfo->set_g_type( Field::get_gda_type_for_glom_type( m_pCombo_Type->get_field_type() ) );
 
-  fieldInfo->set_unique_key(m_pCheck_Unique->get_active());
-  fieldInfo->set_primary_key(m_pCheck_PrimaryKey->get_active());
   fieldInfo->set_auto_increment(m_pCheck_AutoIncrement->get_active());
 
   if(!fieldInfo->get_auto_increment()) //Ignore default_values for auto_increment fields - it's just some obscure postgres code.
@@ -258,6 +263,9 @@ sharedptr<Field> Dialog_FieldDefinition::get_field() const
 
   //Glom-specific details:
 
+  field->set_unique_key(m_pCheck_Unique->get_active());
+  field->set_primary_key(m_pCheck_PrimaryKey->get_active());
+
   field->set_title(m_pEntry_Title->get_text());
 
   //Formatting:
@@ -337,22 +345,22 @@ void Dialog_FieldDefinition::on_combo_lookup_relationship_changed()
 {
   //Get the fields that are avaiable from the new relationship:
 
-  m_pCombo_LookupField->clear_text();
+  m_pCombo_LookupField->clear_items();
 
   //Get the relationship name:
   sharedptr<const Relationship> relationship = m_pCombo_LookupRelationship->get_selected_relationship();
   if(relationship)
   {
     //Get the relationship details:
-    Document_Glom* document = dynamic_cast<Document_Glom*>(get_document());
+    Document* document = dynamic_cast<Document*>(get_document());
     if(document)
     {
       const Glib::ustring to_table = relationship->get_to_table();
       if(!to_table.empty())
       {
         //Get the fields in the other table, and add them to the combo:
-        const type_vecFields fields_in_to_table = get_fields_for_table(to_table);
-        for(type_vecFields::const_iterator iter = fields_in_to_table.begin(); iter != fields_in_to_table.end(); ++iter)
+        const type_vec_fields fields_in_to_table = get_fields_for_table(to_table);
+        for(type_vec_fields::const_iterator iter = fields_in_to_table.begin(); iter != fields_in_to_table.end(); ++iter)
         {
           m_pCombo_LookupField->append_text((*iter)->get_name());
         }
@@ -365,7 +373,7 @@ void Dialog_FieldDefinition::on_combo_lookup_relationship_changed()
 void Dialog_FieldDefinition::on_button_edit_calculation()
 {
   //TODO: Share a global instance, to make this quicker?
-  Glib::RefPtr<Gnome::Glade::Xml> refXml = Gnome::Glade::Xml::create(GLOM_GLADEDIR "glom.glade", "window_field_calculation");
+  Glib::RefPtr<Gtk::Builder> refXml = Gtk::Builder::create_from_file(GLOM_GLADEDIR "glom_developer.glade", "window_field_calculation");
   if(refXml)
   {
     Dialog_FieldCalculation* dialog = 0;
@@ -377,7 +385,7 @@ void Dialog_FieldDefinition::on_button_edit_calculation()
       m_Field->set_calculation( m_pTextView_Calculation->get_buffer()->get_text() );
       dialog->set_field(m_Field, m_table_name);
       //TODO: dialog.set_transient_for(*get_app_window());
-      int response = Glom::Utils::dialog_run_with_help(dialog, "window_field_calculation");
+      const int response = Glom::Utils::dialog_run_with_help(dialog, "window_field_calculation");
       if(response == Gtk::RESPONSE_OK)
       {
         m_pTextView_Calculation->get_buffer()->set_text( dialog->get_field()->get_calculation() );
