@@ -19,8 +19,8 @@
  */
 
 //We need to include this before anything else, to avoid redefinitions:
-#include <glom/libglom/python_embed/py_glom_record.h>
-#include <glom/libglom/python_embed/pygdavalue_conversions.h>
+#include <libglom/python_embed/py_glom_record.h>
+#include <libglom/python_embed/pygdavalue_conversions.h>
 
 #define NO_IMPORT_PYGTK //To avoid a multiple definition in pygtk.
 #include <pygtk/pygtk.h> //For the PyGObject and PyGBoxed struct definitions.
@@ -30,7 +30,7 @@
 #include <eval.h> /* for PyEval_EvalCode */
 
 #include "glom_python.h"
-#include <glom/libglom/data_structure/glomconversions.h>
+#include <libglom/data_structure/glomconversions.h>
 #include <list>
 #include <glib.h> //For g_warning().
 #include <glibmm/i18n.h>
@@ -45,7 +45,7 @@ std::list<Glib::ustring> ustring_tokenize(const Glib::ustring& msg, const Glib::
   std::list<Glib::ustring> result;
   Glib::ustring str = msg;
   bool nocount = false;
-  if (maxParts == -1)
+  if(maxParts == -1)
     nocount = true;
 
   int count = 0;
@@ -82,14 +82,14 @@ void ShowTrace()
 
   PyErr_Fetch(&type, &value, &traceback);
   
-  if (!traceback)
+  if(!traceback)
   {
     std::cerr << "traceback = 0" << std::endl;
   }
 
   PyObject *tracebackModule = PyImport_ImportModule((char*)"traceback");
   gchar* chrRetval = 0;
-  if (tracebackModule != NULL)
+  if(tracebackModule != NULL)
   {
       PyObject* tbList = PyObject_CallMethod(
           tracebackModule,
@@ -99,7 +99,7 @@ void ShowTrace()
           value == NULL ? Py_None : value,
           traceback == NULL ? Py_None : traceback);
       
-      if (!tbList)
+      if(!tbList)
       {
         std::cerr << "format_exception failed" << std::endl;
         return;
@@ -108,7 +108,7 @@ void ShowTrace()
       PyObject* emptyString = PyString_FromString("");
       PyObject* strRetval = PyObject_CallMethod(emptyString, (char*)"join",
             (char*)"O", tbList);
-      if (strRetval)
+      if(strRetval)
         chrRetval = g_strdup(PyString_AsString(strRetval));
     
       Py_DECREF(tbList);
@@ -126,7 +126,7 @@ void ShowTrace()
     Py_XDECREF(value);
     Py_XDECREF(traceback);
   
-  if (chrRetval)
+  if(chrRetval)
   {
     Glib::ustring message = _("Python Error: \n");
     message += chrRetval;
@@ -136,13 +136,27 @@ void ShowTrace()
   g_free(chrRetval);
 }
 
-void glom_execute_python_function_implementation(const Glib::ustring& func_impl, const type_map_fields& field_values, Document_Glom* pDocument, const Glib::ustring& table_name, const Glib::RefPtr<Gnome::Gda::Connection>& opened_connection)
+bool glom_python_module_is_available()
+{
+  PyObject* module_glom = PyImport_ImportModule((char*)"glom"); //TODO: unref this?
+  return module_glom != 0;
+}
+
+bool gda_python_module_is_available()
+{
+  PyObject* module_glom = PyImport_ImportModule((char*)"gda"); //TODO: unref this?
+  return module_glom != 0;
+}
+
+
+
+void glom_execute_python_function_implementation(const Glib::ustring& func_impl, const type_map_fields& field_values, Document* pDocument, const Glib::ustring& table_name, const Glib::RefPtr<Gnome::Gda::Connection>& opened_connection)
 {
   glom_evaluate_python_function_implementation(Field::TYPE_TEXT, func_impl, field_values, pDocument, table_name, opened_connection);
 }
 
 Gnome::Gda::Value glom_evaluate_python_function_implementation(Field::glom_field_type result_type, const Glib::ustring& func_impl,
-    const type_map_fields& field_values, Document_Glom* pDocument, const Glib::ustring& table_name, const Glib::RefPtr<Gnome::Gda::Connection>& opened_connection)
+    const type_map_fields& field_values, Document* pDocument, const Glib::ustring& table_name, const Glib::RefPtr<Gnome::Gda::Connection>& opened_connection)
 {
   //std::cout << "glom_evaluate_python_function_implementation()" << std::endl;
   //for(type_map_fields::const_iterator iter = field_values.begin(); iter != field_values.end(); ++iter)
@@ -177,7 +191,7 @@ Gnome::Gda::Value glom_evaluate_python_function_implementation(Field::glom_field
 
 
   //Allow the function to import from our script library:
-  if (pDocument)
+  if(pDocument)
   {
     const std::vector<Glib::ustring> module_names = pDocument->get_library_module_names();
     for(std::vector<Glib::ustring>::const_iterator iter = module_names.begin(); iter != module_names.end(); ++iter)
@@ -296,20 +310,20 @@ Gnome::Gda::Value glom_evaluate_python_function_implementation(Field::glom_field
         //Deal with the various possible return types:
         bool object_is_gda_value = false;
 
-        GValue value = { 0 };
+        GValue value = {0, {{0}}};
         const int test = pygda_value_from_pyobject(&value, pyResult);
 
         if(test == 0) //-1 means error.
-	  object_is_gda_value = true;
+          object_is_gda_value = true;
 
         if(object_is_gda_value && G_IS_VALUE(&value))
         {
-	  valueResult = Gnome::Gda::Value(&value);
+          valueResult = Gnome::Gda::Value(&value);
           //Make sure that the value is of the expected Gda type:
           //TODO_Performance:
           valueResult = Glom::Conversions::convert_value(valueResult, result_type);
           //std::cout << "DEBUG: glom_evaluate_python_function_implementation(): valueResult Gda type=" << g_type_name(valueResult.get_value_type()) << std::endl;
-	  g_value_unset(&value);
+          g_value_unset(&value);
         }
         else
         {
